@@ -217,7 +217,7 @@ _JS_DST
 <body>
 </body>
 _TECHCRUNCH_SRC
-			<<'_TECHCRUNCH_DST'
+			<<'_TECHCRUNCH_DST',
 <head profile="http://gmpg.org/xfn/11">
 <meta http-equiv="Content-Type" content="text/html; charset=EUC-JP" />
 
@@ -227,6 +227,8 @@ _TECHCRUNCH_SRC
 <body>
 </body>
 _TECHCRUNCH_DST
+			'<header>malformed</head>' =>
+			'<head><meta http-equiv="content-type" content="text/html; charset=EUC-JP"></head><header>malformed</head>',
 		}.each_pair do |src, dst|
 			res = HTTPResponse.new( {:HTTPVersion => '1.1'} )
 			res.content_type = 'text/html'
